==> ring_20191025.1.074a237.tar.gz: ring-project/lrc/translations/lrc_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" sourcelanguage="en" version="2.0">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="315"/>
        <source>Me</source>
        <translation>我</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="60"/>
        <source>Hold</source>
        <translation>暫停通話</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="62"/>
        <source>Talking</source>
        <translation>通話中</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="64"/>
        <source>ERROR</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="66"/>
        <source>Incoming</source>
        <translation>來電</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="68"/>
        <source>Calling</source>
        <translation>正在通話</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="70"/>
        <source>Connecting</source>
        <translation>連接中</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="72"/>
        <source>Searching</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="74"/>
        <source>Inactive</source>
        <translation>不活躍</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="76"/>
        <location filename="../src/api/call.h" line="82"/>
        <source>Finished</source>
        <translation>已結束</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="78"/>
        <source>Timeout</source>
        <translation>逾時</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="80"/>
        <source>Peer busy</source>
        <translation>對方忙碌</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="84"/>
        <source>Communication established</source>
        <translation>已建立通訊</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="135"/>
        <location filename="../src/authority/storagehelper.cpp" line="856"/>
        <source>Invitation received</source>
        <translation>已收到邀請</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="132"/>
        <location filename="../src/authority/storagehelper.cpp" line="854"/>
        <source>Contact added</source>
        <translation>已新增聯絡人</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="106"/>
        <location filename="../src/authority/storagehelper.cpp" line="112"/>
        <location filename="../src/authority/storagehelper.cpp" line="852"/>
        <source>Outgoing call</source>
        <translation>撥出電話</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="108"/>
        <location filename="../src/authority/storagehelper.cpp" line="119"/>
        <source>Incoming call</source>
        <translation>來電</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="115"/>
        <location filename="../src/authority/storagehelper.cpp" line="850"/>
        <source>Missed outgoing call</source>
        <translation>未接去電</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="122"/>
        <source>Missed incoming call</source>
        <translation>未接來電</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="137"/>
        <location filename="../src/authority/storagehelper.cpp" line="858"/>
        <source>Invitation accepted</source>
        <translation>已接受邀請</translation>
    </message>
    <message>
        <location filename="../src/avmodel.cpp" line="312"/>
        <location filename="../src/avmodel.cpp" line="333"/>
        <source>default</source>
        <translation>預設</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="48"/>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="49"/>
        <source>Trying</source>
        <translation>正在嘗試</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="50"/>
        <source>Ringing</source>
        <translation>響鈴中</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="51"/>
        <source>Being Forwarded</source>
        <translation>已轉寄</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="52"/>
        <source>Queued</source>
        <translation>已進入佇列</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="53"/>
        <source>Progress</source>
        <translation>排程</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="54"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="55"/>
        <source>Accepted</source>
        <translation>已接受</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="56"/>
        <source>Multiple Choices</source>
        <translation>多選</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="57"/>
        <source>Moved Permanently</source>
        <translation>永久移動</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="58"/>
        <source>Moved Temporarily</source>
        <translation>暫時移動</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="59"/>
        <source>Use Proxy</source>
        <translation>使用代理伺服器</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="60"/>
        <source>Alternative Service</source>
        <translation>替代服務</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="61"/>
        <source>Bad Request</source>
        <translation>不良的請求</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="62"/>
        <source>Unauthorized</source>
        <translation>未授權</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="63"/>
        <source>Payment Required</source>
        <translation>需要付款</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="64"/>
        <source>Forbidden</source>
        <translation>被禁止</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="65"/>
        <source>Not Found</source>
        <translation>找不到</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="66"/>
        <source>Method Not Allowed</source>
        <translation>不允許的方法</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="67"/>
        <location filename="../src/newcallmodel.cpp" line="87"/>
        <source>Not Acceptable</source>
        <translation>無法接受</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="68"/>
        <source>Proxy Authentication Required</source>
        <translation>需要代理伺服器驗證</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="69"/>
        <source>Request Timeout</source>
        <translation>請求逾時</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="70"/>
        <source>Gone</source>
        <translation>消失</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="71"/>
        <source>Request Entity Too Large</source>
        <translation>請求實體太大</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="72"/>
        <source>Request URI Too Long</source>
        <translation>請求 URI 太長</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="73"/>
        <source>Unsupported Media Type</source>
        <translation>不支援的媒體類型</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="74"/>
        <source>Unsupported URI Scheme</source>
        <translation>不支援的 URI 結構</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="75"/>
        <source>Bad Extension</source>
        <translation>不良的副檔名</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="76"/>
        <source>Extension Required</source>
        <translation>需要副檔名</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="77"/>
        <source>Session Timer Too Small</source>
        <translation>工作階段計時器太小了</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="78"/>
        <source>Interval Too Brief</source>
        <translation>間隔太短</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="79"/>
        <source>Temporarily Unavailable</source>
        <translation>暫時不可用</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="80"/>
        <source>Call TSX Does Not Exist</source>
        <translation>呼叫 TSX 不存在</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="81"/>
        <source>Loop Detected</source>
        <translation>偵測到迴圈</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="82"/>
        <source>Too Many Hops</source>
        <translation>太多跳躍</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="83"/>
        <source>Address Incomplete</source>
        <translation>地址不完整</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="84"/>
        <source>Ambiguous</source>
        <translation>曖昧</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="85"/>
        <source>Busy</source>
        <translation>忙碌</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="86"/>
        <source>Request Terminated</source>
        <translation>請求已終結</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="88"/>
        <source>Bad Event</source>
        <translation>不良的活動</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="89"/>
        <source>Request Updated</source>
        <translation>請求已更新</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="90"/>
        <source>Request Pending</source>
        <translation>請求擱置</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="91"/>
        <source>Undecipherable</source>
        <translation>無法解密</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="92"/>
        <source>Internal Server Error</source>
        <translation>內部伺服器錯誤</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="93"/>
        <source>Not Implemented</source>
        <translation>未實作</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="94"/>
        <source>Bad Gateway</source>
        <translation>不良的閘道</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="95"/>
        <source>Service Unavailable</source>
        <translation>服務不可用</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="96"/>
        <source>Server Timeout</source>
        <translation>伺服器逾時</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="97"/>
        <source>Version Not Supported</source>
        <translation>版本不支援</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="98"/>
        <source>Message Too Large</source>
        <translation>訊息太大</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="99"/>
        <source>Precondition Failure</source>
        <translation>前提條件失敗</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="100"/>
        <source>Busy Everywhere</source>
        <translation>到處都忙碌</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="101"/>
        <source>Call Refused</source>
        <translation>通話被拒絕</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="102"/>
        <source>Does Not Exist Anywhere</source>
        <translation>到處都不存在</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="103"/>
        <source>Not Acceptable Anywhere</source>
        <translation>到處都不接受</translation>
    </message>
</context>
<context>
    <name>lrc::ContactModelPimpl</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="405"/>
        <source>Searchingâ¦</source>
        <translation>正在搜尋</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="765"/>
        <source>Invalid ID</source>
        <translation>無效 ID</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="768"/>
        <source>Registered name not found</source>
        <translation>找不到已註冊的名稱</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="771"/>
        <source>Couldn&apos;t lookupâ¦</source>
        <translation>無法查詢！</translation>
    </message>
</context>
<context>
    <name>lrc::api::ContactModel</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="371"/>
        <source>Bad URI scheme</source>
        <translation>錯誤的 URI 結構</translation>
    </message>
</context>
</TS>

==> ring_20191029.1.3021830.tar.gz: ring-project/lrc/translations/lrc_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" sourcelanguage="en" version="2.0">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="315"/>
        <source>Me</source>
        <translation>我</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="60"/>
        <source>Hold</source>
        <translation>暫停通話</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="62"/>
        <source>Talking</source>
        <translation>通話中</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="64"/>
        <source>ERROR</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="66"/>
        <source>Incoming</source>
        <translation>來電</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="68"/>
        <source>Calling</source>
        <translation>正在通話</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="70"/>
        <source>Connecting</source>
        <translation>連接中</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="72"/>
        <source>Searching</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="74"/>
        <source>Inactive</source>
        <translation>不活躍</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="76"/>
        <location filename="../src/api/call.h" line="82"/>
        <source>Finished</source>
        <translation>已結束</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="78"/>
        <source>Timeout</source>
        <translation>逾時</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="80"/>
        <source>Peer busy</source>
        <translation>對方忙碌</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="84"/>
        <source>Communication established</source>
        <translation>已建立通訊</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="135"/>
        <location filename="../src/authority/storagehelper.cpp" line="856"/>
        <source>Invitation received</source>
        <translation>已收到邀請</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="132"/>
        <location filename="../src/authority/storagehelper.cpp" line="854"/>
        <source>Contact added</source>
        <translation>已新增聯絡人</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="106"/>
        <location filename="../src/authority/storagehelper.cpp" line="112"/>
        <location filename="../src/authority/storagehelper.cpp" line="852"/>
        <source>Outgoing call</source>
        <translation>撥出電話</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="108"/>
        <location filename="../src/authority/storagehelper.cpp" line="119"/>
        <source>Incoming call</source>
        <translation>來電</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="115"/>
        <location filename="../src/authority/storagehelper.cpp" line="850"/>
        <source>Missed outgoing call</source>
        <translation>未接去電</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="122"/>
        <source>Missed incoming call</source>
        <translation>未接來電</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="137"/>
        <location filename="../src/authority/storagehelper.cpp" line="858"/>
        <source>Invitation accepted</source>
        <translation>已接受邀請</translation>
    </message>
    <message>
        <location filename="../src/avmodel.cpp" line="312"/>
        <location filename="../src/avmodel.cpp" line="333"/>
        <source>default</source>
        <translation>預設</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="48"/>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="49"/>
        <source>Trying</source>
        <translation>正在嘗試</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="50"/>
        <source>Ringing</source>
        <translation>響鈴中</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="51"/>
        <source>Being Forwarded</source>
        <translation>已轉寄</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="52"/>
        <source>Queued</source>
        <translation>已進入佇列</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="53"/>
        <source>Progress</source>
        <translation>排程</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="54"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="55"/>
        <source>Accepted</source>
        <translation>已接受</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="56"/>
        <source>Multiple Choices</source>
        <translation>多選</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="57"/>
        <source>Moved Permanently</source>
        <translation>永久移動</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="58"/>
        <source>Moved Temporarily</source>
        <translation>暫時移動</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="59"/>
        <source>Use Proxy</source>
        <translation>使用代理伺服器</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="60"/>
        <source>Alternative Service</source>
        <translation>替代服務</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="61"/>
        <source>Bad Request</source>
        <translation>不良的請求</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="62"/>
        <source>Unauthorized</source>
        <translation>未授權</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="63"/>
        <source>Payment Required</source>
        <translation>需要付款</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="64"/>
        <source>Forbidden</source>
        <translation>被禁止</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="65"/>
        <source>Not Found</source>
        <translation>找不到</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="66"/>
        <source>Method Not Allowed</source>
        <translation>不允許的方法</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="67"/>
        <location filename="../src/newcallmodel.cpp" line="87"/>
        <source>Not Acceptable</source>
        <translation>無法接受</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="68"/>
        <source>Proxy Authentication Required</source>
        <translation>需要代理伺服器驗證</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="69"/>
        <source>Request Timeout</source>
        <translation>請求逾時</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="70"/>
        <source>Gone</source>
        <translation>消失</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="71"/>
        <source>Request Entity Too Large</source>
        <translation>請求實體太大</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="72"/>
        <source>Request URI Too Long</source>
        <translation>請求 URI 太長</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="73"/>
        <source>Unsupported Media Type</source>
        <translation>不支援的媒體類型</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="74"/>
        <source>Unsupported URI Scheme</source>
        <translation>不支援的 URI 結構</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="75"/>
        <source>Bad Extension</source>
        <translation>不良的副檔名</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="76"/>
        <source>Extension Required</source>
        <translation>需要副檔名</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="77"/>
        <source>Session Timer Too Small</source>
        <translation>工作階段計時器太小了</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="78"/>
        <source>Interval Too Brief</source>
        <translation>間隔太短</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="79"/>
        <source>Temporarily Unavailable</source>
        <translation>暫時不可用</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="80"/>
        <source>Call TSX Does Not Exist</source>
        <translation>呼叫 TSX 不存在</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="81"/>
        <source>Loop Detected</source>
        <translation>偵測到迴圈</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="82"/>
        <source>Too Many Hops</source>
        <translation>太多跳躍</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="83"/>
        <source>Address Incomplete</source>
        <translation>地址不完整</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="84"/>
        <source>Ambiguous</source>
        <translation>曖昧</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="85"/>
        <source>Busy</source>
        <translation>忙碌</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="86"/>
        <source>Request Terminated</source>
        <translation>請求已終結</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="88"/>
        <source>Bad Event</source>
        <translation>不良的活動</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="89"/>
        <source>Request Updated</source>
        <translation>請求已更新</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="90"/>
        <source>Request Pending</source>
        <translation>請求擱置</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="91"/>
        <source>Undecipherable</source>
        <translation>無法解密</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="92"/>
        <source>Internal Server Error</source>
        <translation>內部伺服器錯誤</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="93"/>
        <source>Not Implemented</source>
        <translation>未實作</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="94"/>
        <source>Bad Gateway</source>
        <translation>不良的閘道</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="95"/>
        <source>Service Unavailable</source>
        <translation>服務不可用</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="96"/>
        <source>Server Timeout</source>
        <translation>伺服器逾時</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="97"/>
        <source>Version Not Supported</source>
        <translation>版本不支援</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="98"/>
        <source>Message Too Large</source>
        <translation>訊息太大</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="99"/>
        <source>Precondition Failure</source>
        <translation>前提條件失敗</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="100"/>
        <source>Busy Everywhere</source>
        <translation>到處都忙碌</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="101"/>
        <source>Call Refused</source>
        <translation>通話被拒絕</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="102"/>
        <source>Does Not Exist Anywhere</source>
        <translation>到處都不存在</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="103"/>
        <source>Not Acceptable Anywhere</source>
        <translation>到處都不接受</translation>
    </message>
</context>
<context>
    <name>lrc::ContactModelPimpl</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="405"/>
        <source>Searching…</source>
        <translation>正在搜尋……</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="765"/>
        <source>Invalid ID</source>
        <translation>無效 ID</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="768"/>
        <source>Registered name not found</source>
        <translation>找不到已註冊的名稱</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="771"/>
        <source>Couldn&apos;t lookup…</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>lrc::api::ContactModel</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="371"/>
        <source>Bad URI scheme</source>
        <translation>錯誤的 URI 結構</translation>
    </message>
</context>
</TS>
